.. currentmodule:: xarray

===
API 
===

Modules
=======

open_dataset
************
.. automodule:: oceanspy.open_dataset
    :members:

subsample
************
.. automodule:: oceanspy.subsample
    :members:

compute
************
.. automodule:: oceanspy.compute
    :members:

visualize
************
.. automodule:: oceanspy.visualize
    :members:

utils
*****
.. automodule:: oceanspy.utils
    :members:




